#
# spec file for package python-gitlabcis
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-gitlabcis
Version:        1.15.1
Release:        1.1
Summary:        An automated tool that assesses the GitLab CIS benchmarks against a project
License:        MIT
URL:            https://gitlab.com/gitlab-security-oss/cis/gitlabcis/
Source:         https://files.pythonhosted.org/packages/source/g/gitlabcis/gitlabcis-%{version}.tar.gz
BuildRequires:  python-rpm-macros
# SECTION build requirements
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 61.2}
BuildRequires:  %{python_module setuptools_scm >= 8.1.0}
BuildRequires:  %{python_module wheel >= 0.42}
BuildRequires:  %{python_module twine >= 6.1.0}
# /SECTION
# SECTION runtime requirements
# https://gitlab.com/gitlab-security-oss/cis/gitlabcis/-/blob/main/pyproject.toml?ref_type=heads#L61
BuildRequires:  %{python_module PyYAML >= 6.0.2}
BuildRequires:  %{python_module python-gitlab >= 5.6.0}
BuildRequires:  %{python_module tabulate >= 0.9.0}
BuildRequires:  %{python_module tqdm >= 4.67.1}
BuildRequires:  %{python_module defusedxml >= 0.7.1}
BuildRequires:  %{python_module python-dateutil >= 2.9.0.post0}
BuildRequires:  %{python_module gql >= 3.5.2}
# /SECTION
# SECTION test requirements
# BuildRequires:  python_module pytest >= 8.3.4}
# BuildRequires:  python_module yamllint >= 1.35.1}
# BuildRequires:  python_module bandit >= 1.8.3}
# /SECTION
BuildRequires:  fdupes
# https://gitlab.com/gitlab-security-oss/cis/gitlabcis/-/blob/main/pyproject.toml?ref_type=heads#L61
Requires:       python-PyYAML >= 6.0.2
Requires:       python-python-gitlab >= 5.6.0
Requires:       python-tabulate >= 0.9.0
Requires:       python-tqdm >= 4.67.1
Requires:       python-defusedxml >= 0.7.1
Requires:       python-python-dateutil >= 2.9.0.post0
Requires:       python-gql >= 3.5.2
BuildArch:      noarch
%python_subpackages

%description
An automated tool that assesses the GitLab CIS benchmarks against a project.

%prep
%autosetup -p1 -n gitlabcis-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/gitlabcis
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative gitlabcis

%postun
%python_uninstall_alternative gitlabcis

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%python_alternative %{_bindir}/gitlabcis
%{python_sitelib}/gitlabcis
%{python_sitelib}/gitlabcis-%{version}.dist-info

%changelog
* Wed Apr 16 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.15.1:
  * Fix
  - fix: remove non-required detect cmd (#127) (14ff8da)
* Thu Apr 10 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.15.0:
  * Feature
  - feat: Add Group input type controls in build pipelines (&2) &
    (#125) (a5bca5d)
* Tue Apr  8 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.14.0:
  * Documentation
  - docs: add statement for benchmark contributions (3693222)
  * Feature
  - feat: Add group controls for source_code code_changes (&2),
    (#125), (#118) (dac4b1e)
  * Fix
  - fix: Hardpin release dependencies (079c94a)
* Fri Mar 21 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.13.2:
  * Fix
  - fix: add dependency sbom to version control (#124) (d890086)
* Tue Mar 18 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.13.1:
  * Fix
  - fix: add error handling for 404 responses (#117) (06bdb55)
* Mon Mar 17 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.13.0:
  * Feature
  - feat: add final instance type control functions (deployment)
    (#111) (b98fcb9)
* Mon Mar 17 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.12.0:
  * Feature
  - feat: add cli option "--no-ssl-verify" to disable ssl cert
    verifications (#121) (a53ed08)
* Mon Mar 17 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.11.3:
  * Fix
  - fix: add better error handling for 1.1.14 (#120) (ce774b5)
* Mon Mar 17 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.11.2:
  * Fix
  - fix(deps): update dependency gql to v3.5.2 (2bd3d8a)
* Sun Mar  9 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package python-gitlabcis: an automated tool that assesses the
  GitLab CIS benchmarks against a project
